==> odoo13_addon_shopfloor-13.0.2.5.1.dev2-py3-none-any.whl: odoo/addons/shopfloor/tests/__init__.py <==
from . import test_app
from . import test_user
from . import test_menu
from . import test_menu_counters
from . import test_openapi
from . import test_profile
from . import test_actions_change_package_lot
from . import test_actions_data
from . import test_actions_data_detail
from . import test_single_pack_transfer
from . import test_single_pack_transfer_putaway
from . import test_cluster_picking_base
from . import test_cluster_picking_batch
from . import test_cluster_picking_select
from . import test_cluster_picking_scan_line
from . import test_cluster_picking_scan_destination
from . import test_cluster_picking_is_zero
from . import test_cluster_picking_skip
from . import test_cluster_picking_stock_issue
from . import test_cluster_picking_change_pack_lot
from . import test_cluster_picking_unload
from . import test_checkout_base
from . import test_checkout_scan
from . import test_checkout_select
from . import test_checkout_scan_line
from . import test_checkout_select_line
from . import test_checkout_select_package_base
from . import test_checkout_set_qty
from . import test_checkout_scan_package_action
from . import test_checkout_new_package
from . import test_checkout_no_package
from . import test_checkout_list_package
from . import test_checkout_summary
from . import test_checkout_change_packaging
from . import test_checkout_cancel_line
from . import test_checkout_done
from . import test_delivery_base
from . import test_delivery_done
from . import test_delivery_scan_deliver
from . import test_delivery_reset_qty_done_line
from . import test_delivery_reset_qty_done_pack
from . import test_delivery_set_qty_done_pack
from . import test_delivery_set_qty_done_line
from . import test_delivery_list_stock_picking
from . import test_delivery_select
from . import test_location_content_transfer_base
from . import test_location_content_transfer_start
from . import test_location_content_transfer_set_destination_all
from . import test_location_content_transfer_single
from . import test_location_content_transfer_set_destination_package_or_line
from . import test_location_content_transfer_putaway
from . import test_location_content_transfer_mix
from . import test_zone_picking_base
from . import test_zone_picking_start
from . import test_zone_picking_select_picking_type
from . import test_zone_picking_select_line
from . import test_zone_picking_set_line_destination
from . import test_zone_picking_zero_check
from . import test_zone_picking_stock_issue
from . import test_zone_picking_change_pack_lot
from . import test_zone_picking_unload_buffer_lines
from . import test_zone_picking_unload_single
from . import test_zone_picking_unload_all
from . import test_zone_picking_unload_set_destination
from . import test_misc
from . import test_move_action_assign
from . import test_scan_anything
from . import test_stock_split
from . import test_picking_form
from . import test_db_logging

==> odoo13_addon_shopfloor-13.0.3.1.1.dev1-py3-none-any.whl: odoo/addons/shopfloor/tests/__init__.py <==
from . import test_app
from . import test_user
from . import test_menu
from . import test_menu_counters
from . import test_openapi
from . import test_profile
from . import test_actions_change_package_lot
from . import test_actions_data
from . import test_actions_data_detail
from . import test_single_pack_transfer
from . import test_single_pack_transfer_putaway
from . import test_cluster_picking_base
from . import test_cluster_picking_batch
from . import test_cluster_picking_select
from . import test_cluster_picking_scan_line
from . import test_cluster_picking_scan_destination
from . import test_cluster_picking_is_zero
from . import test_cluster_picking_skip
from . import test_cluster_picking_stock_issue
from . import test_cluster_picking_change_pack_lot
from . import test_cluster_picking_unload
from . import test_checkout_base
from . import test_checkout_scan
from . import test_checkout_select
from . import test_checkout_scan_line
from . import test_checkout_scan_line_base
from . import test_checkout_select_line
from . import test_checkout_select_package_base
from . import test_checkout_set_qty
from . import test_checkout_scan_package_action
from . import test_checkout_new_package
from . import test_checkout_no_package
from . import test_checkout_list_package
from . import test_checkout_summary
from . import test_checkout_change_packaging
from . import test_checkout_cancel_line
from . import test_checkout_done
from . import test_delivery_base
from . import test_delivery_done
from . import test_delivery_scan_deliver
from . import test_delivery_reset_qty_done_line
from . import test_delivery_reset_qty_done_pack
from . import test_delivery_set_qty_done_pack
from . import test_delivery_set_qty_done_line
from . import test_delivery_list_stock_picking
from . import test_delivery_select
from . import test_location_content_transfer_base
from . import test_location_content_transfer_start
from . import test_location_content_transfer_set_destination_all
from . import test_location_content_transfer_single
from . import test_location_content_transfer_set_destination_package_or_line
from . import test_location_content_transfer_putaway
from . import test_location_content_transfer_mix
from . import test_zone_picking_base
from . import test_zone_picking_start
from . import test_zone_picking_select_picking_type
from . import test_zone_picking_select_line
from . import test_zone_picking_set_line_destination
from . import test_zone_picking_zero_check
from . import test_zone_picking_stock_issue
from . import test_zone_picking_change_pack_lot
from . import test_zone_picking_unload_buffer_lines
from . import test_zone_picking_unload_single
from . import test_zone_picking_unload_all
from . import test_zone_picking_unload_set_destination
from . import test_misc
from . import test_move_action_assign
from . import test_scan_anything
from . import test_stock_split
from . import test_picking_form
